@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Sunday October 24, 2004 at 12:40:12 PM PDT
+ *  It has been AutoGen-ed  Friday December 31, 2004 at 08:18:56 PM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
@@ -46,9 +46,6 @@
 /* START === USER HEADERS === DO NOT CHANGE THIS COMMENT */
 
 #include "autogen.h"
-#ifdef DEBUG_ENABLED
-#  define DEBUG
-#endif
 
 /* END   === USER HEADERS === DO NOT CHANGE THIS COMMENT */
 
