@@ -1,12 +1,12 @@
 
 /*
- *  $Id: expOutput.c,v 1.35 2003/12/27 15:05:43 bkorb Exp $
+ *  $Id: expOutput.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
  *
  *  This module implements the output file manipulation function
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -330,8 +330,19 @@ ag_scm_out_push_new( SCM new_file )
         unlink( pzNewFile );
         addWriteAccess( pzNewFile );
         p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
-
-    } else {
+    }
+#   if defined(ENABLE_FMEMOPEN)
+    else if (! HAVE_OPT( NO_FMEMOPEN ))
+#   else
+    else
+#   endif
+    {
+        /*
+         *  IF we do not have fopencookie(3GNU) or funopen(3BSD), then this
+         *  block is a pure "else" clause.  If we do have one of those, then
+         *  the block is executed when a file name is not s specified *and*
+         *  --no-fmemopen was *not* selected.
+         */
         tSCC* pzTemp = NULL;
         int tmpfd;
 
@@ -356,6 +367,19 @@ ag_scm_out_push_new( SCM new_file )
         p->pFile  = fopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+" );
         close( tmpfd );
     }
+#   ifdef ENABLE_FMEMOPEN
+    else {
+        /*
+         *  This block is a pure "else" clause that is only compiled if neither
+         *  "fopencookie" nor "funopen" is available in the local C library.
+         *  Otherwise, anonymous output without --no-fmemopen being selected
+         *  will get us here.
+         */
+        p->pFile  = fmemopen( NULL, 0, "wb+" );
+        pzNewFile = "in-mem buffer";
+        p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
+    }
+#   endif /* ENABLE_FMEMOPEN */
 
     if (p->pFile == NULL)
         AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
