@@ -1,6 +1,6 @@
 
 /*
- *  save.c  $Id: save.c,v 2.31 2004/07/22 02:46:23 bkorb Exp $
+ *  save.c  $Id: save.c,v 4.2 2005/01/01 04:18:03 bkorb Exp $
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -369,8 +369,9 @@ optionSaveFile( tOptions* pOpts )
             /*
              *  The return values for ctime(), localtime(), and gmtime()
              *  normally point to static data that is overwritten by each call.
+             *  The test to detect allocated ctime, so we leak the memory.
              */
-            free( (void*)pzTime );
+            free( pzTime );
 #endif
         }
 
@@ -451,7 +452,7 @@ optionSaveFile( tOptions* pOpts )
                     /*
                      *  bit flag strings get allocated
                      */
-                    free( (void*)p->pzLastArg );
+                    free( (char*)p->pzLastArg );
                 p->pzLastArg = val;
                 break;
             }
